==> clash-ghc-1.8.2-58-riscv64.pkg.tar.zst: usr/share/haskell/register/clash-ghc.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 clash-ghc
version:              1.8.2
visibility:           public
id:                   clash-ghc-1.8.2-I2JAzagvx86KFdM0s6RZI5
key:                  clash-ghc-1.8.2-I2JAzagvx86KFdM0s6RZI5
license:              BSD-2-Clause
copyright:
    Copyright © 2012-2016, University of Twente,
    2016-2017, Myrtle Software Ltd,
    2017-2019, QBayLogic B.V., Google Inc.

maintainer:           QBayLogic B.V. <devops@qbaylogic.com>
author:               The Clash Authors
homepage:             https://clash-lang.org/
synopsis:
    Clash: a functional hardware description language - GHC frontend

description:
    Clash is a functional hardware description language that borrows both its
    syntax and semantics from the functional programming language Haskell. The
    Clash compiler transforms these high-level descriptions to low-level
    synthesizable VHDL, Verilog, or SystemVerilog.

    Features of Clash:

    * Strongly typed, but with a very high degree of type inference, enabling both
    safe and fast prototyping using concise descriptions.

    * Interactive REPL: load your designs in an interpreter and easily test all
    your component without needing to setup a test bench.

    * Higher-order functions, with type inference, result in designs that are
    fully parametric by default.

    * Synchronous sequential circuit design based on streams of values, called
    @Signal@s, lead to natural descriptions of feedback loops.

    * Support for multiple clock domains, with type safe clock domain crossing.


    This package provides:

    * Clash Compiler binary using GHC/Haskell as a frontend


    Prelude library: <https://hackage.haskell.org/package/clash-prelude>

category:             Hardware
abi:                  921296a3a72f3b38662ecbf248e0a5f9
exposed:              True
exposed-modules:
    Clash.GHC.Evaluator Clash.GHC.Evaluator.Primitive
    Clash.GHC.GenerateBindings Clash.GHC.LoadModules
    Clash.GHC.NetlistTypes Clash.GHC.PartialEval
    Clash.GHC.PartialEval.Eval Clash.GHC.PartialEval.Primitive
    Clash.GHC.PartialEval.Quote Clash.GHCi.Common Clash.Main

hidden-modules:
    Clash.GHCi.Leak Clash.GHCi.UI Clash.GHCi.UI.Info
    Clash.GHCi.UI.Monad Clash.GHC.ClashFlags Clash.GHC.GHC2Core
    Clash.GHC.LoadInterfaceFiles Clash.GHC.Util Data.Text.Extra
    Paths_clash_ghc Clash.GHCi.Util Clash.GHCi.UI.Tags

import-dirs:          /usr/lib/ghc-9.4.8/site-local/clash-ghc-1.8.2
library-dirs:         /usr/lib/ghc-9.4.8/site-local/clash-ghc-1.8.2
library-dirs-static:  /usr/lib/ghc-9.4.8/site-local/clash-ghc-1.8.2
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/clash-ghc
hs-libraries:         HSclash-ghc-1.8.2-I2JAzagvx86KFdM0s6RZI5
depends:
    Cabal-3.8.1.0 array-0.5.4.0 base-4.17.2.1 bytestring-0.11.5.3
    clash-lib-1.8.2-LoCb8VaUA0CVnGE5PFASg
    clash-prelude-1.8.2-5afVdj61OQWLI5zcxExRk3 containers-0.6.7
    data-binary-ieee754-0.4.4-3K4wyZ8KRa1CgKftL8GYsk deepseq-1.4.8.0
    directory-1.3.7.1 exceptions-0.10.5
    extra-1.7.16-KxrHBQWVwMp2M62XitBte8 filepath-1.4.2.2 ghc-9.4.8
    ghc-bignum-1.3 ghc-boot-9.4.8 ghc-prim-0.9.1
    ghc-typelits-extra-0.4.6-BudZI0fRYDRJzQQbvjQ7mD
    ghc-typelits-knownnat-0.7.12-13eEO4hT8ZWhHEhTJYj2F
    ghc-typelits-natnormalise-0.7.11-CkTDgrffrZhAG0i5iclypo ghci-9.4.8
    hashable-1.4.4.0-HF0gObldLcB4LirfpxeD3R haskeline-0.8.2
    lens-5.3.1-57CGCDOUfQCLkJSlnZcVUR mtl-2.2.2
    primitive-0.9.1.0-CwYB76NvKpqXNq7rVKe89 process-1.6.18.0
    reflection-2.1.9-E7hB6KmEkOQ92strb8osnl
    split-0.2.5-Dujwwofvw7aEFmjRmWhj9Q
    string-interpolate-0.3.4.0-6EMlcsDHQDnHiHZAbHjqrU
    template-haskell-2.19.0.0 text-2.0.2 time-1.12.2
    transformers-0.5.6.2 uniplate-1.6.13-JXA4VCV4vwKlFPDh1oFOb
    unix-2.7.3 unordered-containers-0.2.20-89DcpQLd7HI30AdGz5XyJk
    utf8-string-1.0.2-D0oARDqSiCF3CIA0pPBIDm
    vector-0.13.2.0-AtXaKVcIvtCInBZOrzSe57

haddock-interfaces:   /usr/share/doc/clash-ghc/html/clash-ghc.haddock
haddock-html:         /usr/share/doc/clash-ghc/html
' | '/usr/bin/ghc-pkg-9.4.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> clash-ghc-1.8.2-81-riscv64.pkg.tar.zst: usr/share/haskell/register/clash-ghc.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 clash-ghc
version:              1.8.2
visibility:           public
id:                   clash-ghc-1.8.2-1vPf55XqraMIQVTgxdAHdL
key:                  clash-ghc-1.8.2-1vPf55XqraMIQVTgxdAHdL
license:              BSD-2-Clause
copyright:
    Copyright © 2012-2016, University of Twente,
    2016-2017, Myrtle Software Ltd,
    2017-2019, QBayLogic B.V., Google Inc.

maintainer:           QBayLogic B.V. <devops@qbaylogic.com>
author:               The Clash Authors
homepage:             https://clash-lang.org/
synopsis:
    Clash: a functional hardware description language - GHC frontend

description:
    Clash is a functional hardware description language that borrows both its
    syntax and semantics from the functional programming language Haskell. The
    Clash compiler transforms these high-level descriptions to low-level
    synthesizable VHDL, Verilog, or SystemVerilog.

    Features of Clash:

    * Strongly typed, but with a very high degree of type inference, enabling both
    safe and fast prototyping using concise descriptions.

    * Interactive REPL: load your designs in an interpreter and easily test all
    your component without needing to setup a test bench.

    * Higher-order functions, with type inference, result in designs that are
    fully parametric by default.

    * Synchronous sequential circuit design based on streams of values, called
    @Signal@s, lead to natural descriptions of feedback loops.

    * Support for multiple clock domains, with type safe clock domain crossing.


    This package provides:

    * Clash Compiler binary using GHC/Haskell as a frontend


    Prelude library: <https://hackage.haskell.org/package/clash-prelude>

category:             Hardware
abi:                  6246322fc67a925af9ab9ee7f47c162f
exposed:              True
exposed-modules:
    Clash.GHC.Evaluator Clash.GHC.Evaluator.Primitive
    Clash.GHC.GenerateBindings Clash.GHC.LoadModules
    Clash.GHC.NetlistTypes Clash.GHC.PartialEval
    Clash.GHC.PartialEval.Eval Clash.GHC.PartialEval.Primitive
    Clash.GHC.PartialEval.Quote Clash.GHCi.Common Clash.Main

hidden-modules:
    Clash.GHCi.Leak Clash.GHCi.UI Clash.GHCi.UI.Info
    Clash.GHCi.UI.Monad Clash.GHC.ClashFlags Clash.GHC.GHC2Core
    Clash.GHC.LoadInterfaceFiles Clash.GHC.Util Data.Text.Extra
    Paths_clash_ghc Clash.GHCi.Util Clash.GHCi.UI.Tags

import-dirs:          /usr/lib/ghc-9.4.8/site-local/clash-ghc-1.8.2
library-dirs:         /usr/lib/ghc-9.4.8/site-local/clash-ghc-1.8.2
library-dirs-static:  /usr/lib/ghc-9.4.8/site-local/clash-ghc-1.8.2
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/clash-ghc
hs-libraries:         HSclash-ghc-1.8.2-1vPf55XqraMIQVTgxdAHdL
depends:
    Cabal-3.8.1.0 array-0.5.4.0 base-4.17.2.1 bytestring-0.11.5.3
    clash-lib-1.8.2-w7WUdFXEkjJUtaQMiiSgG
    clash-prelude-1.8.2-IGPGYkmUmuk5AxdyESnsDL containers-0.6.7
    data-binary-ieee754-0.4.4-3K4wyZ8KRa1CgKftL8GYsk deepseq-1.4.8.0
    directory-1.3.7.1 exceptions-0.10.5
    extra-1.7.16-CyTEZvSfBxsKCwY9ZtJE7E filepath-1.4.2.2 ghc-9.4.8
    ghc-bignum-1.3 ghc-boot-9.4.8 ghc-prim-0.9.1
    ghc-typelits-extra-0.4.8-Kacwz6ieaPyJMYv5cMpg1E
    ghc-typelits-knownnat-0.7.12-Fcf1aBYEjn93PYRTlWLEnN
    ghc-typelits-natnormalise-0.7.11-IXHhLOL6PX69JwJFdIA1G7 ghci-9.4.8
    hashable-1.4.7.0-KrA5CwhmktQ6Qu5a4JCqq7 haskeline-0.8.2
    lens-5.3.3-1zYcQilqoBK5EhYwkXjOnb mtl-2.2.2
    primitive-0.9.1.0-1TuYyil4nabJdMHni5vWH process-1.6.18.0
    reflection-2.1.9-1SRzj82e1StE0xJDK4bUO2
    split-0.2.5-Dujwwofvw7aEFmjRmWhj9Q
    string-interpolate-0.3.4.0-GqcBTkb5hyW1EHq3eTNtoJ
    template-haskell-2.19.0.0 text-2.0.2 time-1.12.2
    transformers-0.5.6.2 uniplate-1.6.13-6AZxRZigT9K4tvBk80lMWK
    unix-2.7.3 unordered-containers-0.2.20.1-JRJBW0Nl9iEJULI134IWXM
    utf8-string-1.0.2-D0oARDqSiCF3CIA0pPBIDm
    vector-0.13.2.0-DhQEcquLn8PDmAHUsOvAGS

haddock-interfaces:   /usr/share/doc/clash-ghc/html/clash-ghc.haddock
haddock-html:         /usr/share/doc/clash-ghc/html
' | '/usr/bin/ghc-pkg-9.4.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
